@@ -1,12 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
  
 #include "browser.h"
@@ -21,7 +22,12 @@
 #include <QDesktopServices>
 #include <QUrl>
 #include <QApplication>
-#include <QDesktopWidget>
+#include <QScreen>
+#include <QWindow>
+#include <QGuiApplication>
+
+
+
 
 #include "geticon.h"
 #include "theme.h"
@@ -43,11 +49,16 @@ QSettings *config=new QSettings(QCoreApplication::applicationDirPath()+"/texmake
 QSettings *config=new QSettings(QSettings::IniFormat,QSettings::UserScope,"xm1","texmakerhtmlview");
 #endif
 config->beginGroup( "htmlviewer" );
-QRect screen = QApplication::desktop()->screenGeometry();
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+   QRect screen = QWidget::screen()->geometry();
+ #else
+  QRect screen = (window() && window()->windowHandle() ? window()->windowHandle()->screen()->geometry() : QGuiApplication::primaryScreen()->geometry());
+#endif
 int w= config->value( "Geometries/MainwindowWidth",screen.width()/2).toInt();
 int h= config->value( "Geometries/MainwindowHeight",screen.height()-150).toInt() ;
 int x= config->value( "Geometries/MainwindowX",screen.width()/2).toInt();
 int y= config->value( "Geometries/MainwindowY",30).toInt() ;
+
 resize(w,h);
 move(x,y);
 windowstate=config->value("MainWindowState").toByteArray();
@@ -167,14 +178,13 @@ pdffichier.remove("%");
 pdffichier=pdffichier+".pdf";
 QString tempDir=QDir::tempPath();
 pdffichier=tempDir+"/"+pdffichier;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 view->page()->printToPdf(pdffichier);
+#else
+view->printToPdf(pdffichier);
+#endif
 QFileInfo fic(pdffichier);
 if (fic.exists() && fic.isReadable() ) QDesktopServices::openUrl(QUrl("file://"+pdffichier));
-// QPrinter printer;
-// QPrintDialog *dialog = new QPrintDialog(&printer, this);
-// dialog->setWindowTitle(tr("Print"));
-// if (dialog->exec() != QDialog::Accepted) return;
-// view->page()->mainFrame()->print(&printer);
 }
 
 void Browser::Find()
