@@ -1,14 +1,16 @@
 /***************************************************************************
- *   copyright       : (C) 2012-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
- *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
+ *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
+
 /*
 
 Copyright 2012 Adam Reichold
@@ -30,6 +32,11 @@ modified by Pascal Brachet
 #include <QApplication>
 #include <QInputDialog>
 #include <QLineEdit>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    #include <QtCore/QTextCodec>
+#else
+    #include <QtCore5Compat/QTextCodec>
+#endif
 
 bool DocumentView::s_openUrl = false;
 
@@ -364,6 +371,7 @@ return m_pages.at(0)->scaleFactor();
 
 void DocumentView::setScaleFactor(qreal scaleFactor)
 {
+
 if (m_pages.count()<1) return;
     if(m_scaleFactor != scaleFactor && scaleFactor >= s_minimumScaleFactor && scaleFactor <= s_maximumScaleFactor)
     {
@@ -380,7 +388,6 @@ if (m_pages.count()<1) return;
 // 	    viewport()->update();
 // #endif
         }
-
         emit scaleFactorChanged(m_scaleFactor);
     }
 }
@@ -775,6 +782,9 @@ void DocumentView::on_pages_linkClicked(const QString& url)
 void DocumentView::resizeEvent(QResizeEvent* event)
 {
     QGraphicsView::resizeEvent(event);
+    emit sizehaschanged();
+
+
 
     if(m_scaleMode != ScaleFactor)
     {
@@ -836,8 +846,8 @@ if(event->modifiers() & Qt::MetaModifier) {
 	qtKeyCode += Qt::META;
 }
 QKeySequence s1 = QKeySequence(qtKeyCode);
-if (hasFocus() && (s1.matches(QKeySequence(Qt::CTRL + Qt::Key_Left))==QKeySequence::ExactMatch)) rotateLeft();
-else if (hasFocus() && (s1.matches(QKeySequence(Qt::CTRL + Qt::Key_Right))==QKeySequence::ExactMatch)) rotateRight();
+if (hasFocus() && (s1.matches(QKeySequence(Qt::CTRL  | Qt::Key_Left))==QKeySequence::ExactMatch)) rotateLeft();
+else if (hasFocus() && (s1.matches(QKeySequence(Qt::CTRL  | Qt::Key_Right))==QKeySequence::ExactMatch)) rotateRight();
 else QGraphicsView::keyPressEvent(event);
 }
 
@@ -907,7 +917,7 @@ void DocumentView::wheelEvent(QWheelEvent* event)
 if (m_pages.count()<1) return;
     if(event->modifiers() == Qt::ControlModifier)
     {
-        if(event->delta() > 0)
+        if(event->angleDelta().x() > 0)
         {
             emit requestZoomIn();//zoomIn();
         }
@@ -921,7 +931,7 @@ if (m_pages.count()<1) return;
     }
     else if(event->modifiers() == Qt::ShiftModifier)
     {
-        if(event->delta() > 0)
+        if(event->angleDelta().x() > 0)
         {
             rotateLeft();
         }
@@ -937,7 +947,7 @@ if (m_pages.count()<1) return;
     {
         if(!m_continuousMode)
         {
-            if(event->delta() > 0 && verticalScrollBar()->value() == verticalScrollBar()->minimum() && m_currentPage > 1)
+            if(event->angleDelta().x() > 0 && verticalScrollBar()->value() == verticalScrollBar()->minimum() && m_currentPage > 1)
             {
                 previousPage();
 
@@ -946,7 +956,7 @@ if (m_pages.count()<1) return;
                 event->accept();
                 return;
             }
-            else if(event->delta() < 0 && verticalScrollBar()->value() == verticalScrollBar()->maximum() && m_currentPage != currentPageForPage(m_numberOfPages))
+            else if(event->angleDelta().x() < 0 && verticalScrollBar()->value() == verticalScrollBar()->maximum() && m_currentPage != currentPageForPage(m_numberOfPages))
             {
                 nextPage();
 
@@ -1062,6 +1072,7 @@ else page->setPhysicalDpi(physicalDpiX(), physicalDpiY());
         connect(page, SIGNAL(linkClicked(QString)), SLOT(on_pages_linkClicked(QString)));
 	connect(page, SIGNAL(syncpage(int, const QPointF&)), this, SLOT(on_syncpage(int, const QPointF&)));
 	connect(page, SIGNAL(wantPngExport(int)), this, SLOT(pngExport(int)));
+    connect(page, SIGNAL(wantCheckGrammar(int)), this, SLOT(checkSpellGrammarPage(int)));
 	connect(page, SIGNAL(wantNumWords()), this, SLOT(countWords()));
 	connect(page, SIGNAL(wantNumPageWords(int)), this, SLOT(countPageWords(int)));
 	connect(page, SIGNAL(wantOpenLocation()), this, SLOT(openFileBrowser()));
@@ -1369,6 +1380,78 @@ if ( !fn.isEmpty() )
   }  
 }
 
+void DocumentView::checkSpellGrammarPage(int page)
+{
+QTextCodec *codec = QTextCodec::codecForName("UTF-8");
+QString pdf_text="";
+QString pdf_content="";
+QString line="";
+pdf_text=m_document->checkTextAt(page, m_pages.at(page)->boundingRect(), m_pages.at(page)->boundingRect());
+
+QTextStream tsSource( &pdf_text,QIODevice::ReadOnly );
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+tsSource.setCodec(codec);
+#else
+tsSource.setEncoding(QStringConverter::Encoding::Utf8);
+#endif
+while (!tsSource.atEnd())
+	{
+    line=tsSource.readLine().simplified();
+    line.remove(QString(QChar(0x0002)));
+	pdf_content+="<p>"+line+"</p>\n";
+	}
+QStringList items;
+items << "en" << "es" << "fr"  <<"pt" << "de" << "it" << "nl" << "ja-JP" << "km-KH" << "ru-RU" << "zh-CN" << "ar" << "sv" << "no" << "nb" << "ast-ES" <<  "be-BY" << "br-FR" << "ca-ES" << "ca-ES-valencia" <<  "da-DK" << "en-AU" <<  "en-CA" << "en-GB" << "en-NZ" << "en-US" << "en-ZA" << "de-AT" << "de-CH" << "de-DE" << "el-GR" <<  "es-AR" << "fa" << "ga-IE" << "gl-ES"  << "nl-BE" << "pl-PL" << "pt-AO" << "pt-BR" << "pt-MZ" << "pt-PT" << "ro-RO" << "sk-SK" << "sl-SI" << "ta-IN" << "tl-PH" << "uk-UA";
+bool ok;
+QString lang="en";
+int current=0;
+QString locale = QString(QLocale::system().name()).left(2);
+current=items.indexOf(locale);
+if (current<0) current=0;
+QString item = QInputDialog::getItem(this, "Texmaker",tr("Language:"), items, current, false, &ok);
+if (ok && !item.isEmpty()) lang=item;
+QString code=QString::fromUtf8("<!-- Generated by Texmaker -->\n");
+QFile templatefile;
+templatefile.setFileName(":/grammar/checkgrammar.txt");
+templatefile.open(QIODevice::ReadOnly);
+QTextStream t(&templatefile);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+t.setCodec(codec);
+#else
+t.setEncoding(QStringConverter::Encoding::Utf8);
+#endif
+while (!t.atEnd())
+	{
+	code+= t.readLine()+"\n";
+	}
+templatefile.close();
+code.replace("#CONTENT#",pdf_content);
+code.replace("#LANG#",lang);
+QString tempDir=QDir::tempPath();
+QString prefixFile=QDir::homePath();
+prefixFile="texmaker_temp_grammar_"+prefixFile.section('/',-1);
+prefixFile=QString(QUrl::toPercentEncoding(prefixFile));
+prefixFile.remove("%");
+QString tempFile=tempDir+"/"+prefixFile+".html";
+
+QFile fi_html(tempFile);
+if (!fi_html.open(QIODevice::WriteOnly)) return;
+fi_html.write(codec->fromUnicode(code));
+fi_html.close();
+#ifdef INTERNAL_BROWSER
+if (grammarWindow)
+  {
+  if (!grammarWindow->isClosed) grammarWindow->close();
+  delete grammarWindow;
+  }
+grammarWindow=new Browser("file:///"+tempFile,false, 0);
+grammarWindow->raise();
+grammarWindow->show();
+#else
+QDesktopServices::openUrl("file:///"+tempFile);
+#endif
+}
+
 void DocumentView::countPageWords(int page)
 {
 QString pdf_text="";
