@@ -1,14 +1,17 @@
 /***************************************************************************
- *   copyright       : (C) 2012-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
- *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
+ *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
+
+
 /*
 
 Copyright 2012 Adam Reichold
@@ -33,6 +36,10 @@ modified by Pascal Brachet
 #include "presentationview.h"
 #include "qpdfbookmarkmodel.h"
 
+#ifdef INTERNAL_BROWSER
+#include "browser.h"
+#endif
+
 class DocumentView : public QGraphicsView
 {
     Q_OBJECT
@@ -127,6 +134,7 @@ signals:
     void syncpage(int, const QPointF&);
     void requestZoomIn();
     void requestZoomOut();
+    void sizehaschanged();
 
 
 public slots:
@@ -158,6 +166,7 @@ public slots:
     void pngExport(int page);
     void countPageWords(int page);
     void openFileBrowser();
+    void checkSpellGrammarPage(int page);
 
 protected slots:
     void on_verticalScrollBar_valueChanged(int value);
@@ -245,6 +254,10 @@ private:
 
     void prepareHighlight();
 
+    #ifdef INTERNAL_BROWSER
+    QPointer<Browser> browserWindow, grammarWindow;
+    #endif
+
 
 
 
