@@ -1,14 +1,15 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
+ *                                                                         *
  *   addons by Luis Silvestre, Julián Moreno Patiño                        *
  *   contains some code from CLedit (C) 2010 Heinz van Saanen -GPL         *
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "latexeditor.h"
@@ -29,15 +30,19 @@
 #include <QModelIndex>
 #include <QAbstractItemModel>
 #include <QScrollBar>
-#include <QTextCodec>
 #include <QFile>
 #include <QFileInfo>
 #include <QTextDocumentFragment>
 #include <QFuture>
 #include <QtCore>
 #include <QtConcurrent>
-#include <QScriptValue>
-//#include <QPlatformInputContext>
+#include <QRegularExpression>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    #include <QtCore/QTextCodec>
+#else
+    #include <QtCore5Compat/QTextCodec>
+#endif
+
 
 
 #include "blockdata.h"
@@ -121,7 +126,7 @@ if ((tagStart!=-1) && ((tagComment==-1) || ((tagComment!=-1) && (tagStart<=tagCo
 tagStart=tagEnd=offset=0;
 numLeftPar=0;
 s=text; 
-tagStart=s.indexOf(QRegExp("\\\\"+struct_level3+"\\*?[\\{\\[]"), tagEnd);
+tagStart=s.indexOf(QRegularExpression("\\\\"+struct_level3+"\\*?[\\{\\[]"), tagEnd);
 tagEnd=-1;
 offset=tagStart;
 	if ((tagStart!=-1) && ((tagComment==-1) || ((tagComment!=-1) && (tagStart<=tagComment))))
@@ -159,7 +164,7 @@ if (!found)
 tagStart=tagEnd=offset=0;
 numLeftPar=0;
 s=text;
-tagStart=s.indexOf(QRegExp("\\\\"+struct_level4+"\\*?[\\{\\[]"), tagEnd);
+tagStart=s.indexOf(QRegularExpression("\\\\"+struct_level4+"\\*?[\\{\\[]"), tagEnd);
 tagEnd=-1;
 offset=tagStart;
 if ((tagStart!=-1) && ((tagComment==-1) || ((tagComment!=-1) && (tagStart<=tagComment))))
@@ -198,7 +203,7 @@ if (!found)
 tagStart=tagEnd=offset=0;
 numLeftPar=0;
 s=text;
-tagStart=s.indexOf(QRegExp("\\\\"+struct_level5+"\\*?[\\{\\[]"), tagEnd);
+tagStart=s.indexOf(QRegularExpression("\\\\"+struct_level5+"\\*?[\\{\\[]"), tagEnd);
 tagEnd=-1;
 offset=tagStart;
 if ((tagStart!=-1) && ((tagComment==-1) || ((tagComment!=-1) && (tagStart<=tagComment))))
@@ -236,7 +241,7 @@ if (!found)
 //// block ////
 tagStart=tagEnd=offset=0;
 s=text;
-tagStart=s.indexOf(QRegExp("\\\\begin\\{block\\}\\*?[\\{\\[]"), tagEnd);
+tagStart=s.indexOf(QRegularExpression("\\\\begin\\{block\\}\\*?[\\{\\[]"), tagEnd);
 offset=tagStart;
 if ((tagStart!=-1) && ((tagComment==-1) || ((tagComment!=-1) && (tagStart<=tagComment))))
 	{
@@ -308,7 +313,7 @@ if (!found)
 tagStart=tagEnd=offset=0;
 numLeftPar=0;
 s=text;
-tagStart=s.indexOf(QRegExp("\\\\"+struct_level1+"\\*?[\\{\\[]"), tagEnd);
+tagStart=s.indexOf(QRegularExpression("\\\\"+struct_level1+"\\*?[\\{\\[]"), tagEnd);
 tagEnd=-1;
 offset=tagStart;
 if ((tagStart!=-1) && ((tagComment==-1) || ((tagComment!=-1) && (tagStart<=tagComment))))
@@ -347,7 +352,7 @@ if (!found)
 tagStart=tagEnd=offset=0;
 numLeftPar=0;
 s=text;
-tagStart=s.indexOf(QRegExp("\\\\"+struct_level2+"\\*?[\\{\\[]"), tagEnd);
+tagStart=s.indexOf(QRegularExpression("\\\\"+struct_level2+"\\*?[\\{\\[]"), tagEnd);
 tagEnd=-1;
 offset=tagStart;
 if ((tagStart!=-1) && ((tagComment==-1) || ((tagComment!=-1) && (tagStart<=tagComment))))
@@ -461,7 +466,7 @@ return newstruct;
 LatexEditor::LatexEditor(QWidget *parent,QFont & efont, QList<QColor> edcolors, QList<QColor> hicolors,bool inlinespelling,QString ignoredWords,Hunspell *spellChecker,bool tabspaces,int tabwidth,const QKeySequence viewfocus, QString name,QStringList ulist) : QPlainTextEdit(parent),c(0),lastSaveRevision(0)
 {
   
-QScriptValue appContext = fScriptEngine.newQObject(this); 
+QJSValue appContext = fScriptEngine.newQObject(this);
 fScriptEngine.globalObject().setProperty("TM", appContext);
 
 fname=name;
@@ -499,7 +504,11 @@ encoding="";
 setFont(efont);
 tabWidth=tabwidth;
 tabSpaces=tabspaces;
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 setTabStopWidth(fontMetrics().width(" ")*tabWidth);
+#else
+setTabStopDistance(fontMetrics().horizontalAdvance(" ")*tabWidth);
+#endif
 setTabChangesFocus(false);
 endBlock=-1;
 foldableLines.clear();
@@ -536,7 +545,7 @@ connect(this, SIGNAL(cursorPositionChanged()), this, SLOT(matchAll()));
 connect(this, SIGNAL(blockCountChanged(int)), this, SLOT(requestNewNumLines(int)));
 
 //connect(this, SIGNAL(cursorPositionChanged()), this, SLOT(matchLat()));
-//grabShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Tab), Qt::WidgetShortcut);
+//grabShortcut(QKeySequence(Qt::SHIFT  | Qt::Key_Tab), Qt::WidgetShortcut);
 //setCenterOnScroll(true);
 setFocusPolicy(Qt::WheelFocus);
 setFocus();
@@ -577,7 +586,7 @@ void LatexEditor::paintEvent(QPaintEvent *event)
 {
 QPainter painter(viewport());
 QColor selBlendColor=colorHighlight;
-QColor blCol = selBlendColor.dark( 140 );
+QColor blCol = selBlendColor.darker( 140 );
 blCol.setAlphaF( 0.2 );
 QRect rect = cursorRect();
 rect.setX(0);
@@ -669,7 +678,12 @@ if (inBlockSelectionMode
 	&& block.position() >= blockSelection.firstBlock.block().position()
 	&& block.position() <= blockSelection.lastBlock.block().position()) {
     QString text = block.text();
+
+    #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
     qreal spacew = QFontMetricsF(font()).width(QLatin1Char(' '));
+    #else
+    qreal spacew = QFontMetricsF(font()).horizontalAdvance(QLatin1Char(' '));
+    #endif
 
     int offset = 0;
     int relativePos  =  blockSelection.positionAtColumn(text, blockSelection.firstVisualColumn, &offset);
@@ -732,14 +746,22 @@ if (inBlockSelectionMode
                     w = line.cursorToX(relativePos + 1) - x;
                     if (doc->characterAt(context.cursorPosition) == QLatin1Char('\t')) {
                         doSelection = false;
-                        qreal space = QFontMetricsF(layout->font()).width(QLatin1Char(' '));
+                            #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+                            qreal space = QFontMetricsF(layout->font()).width(QLatin1Char(' '));
+                            #else
+                            qreal space = QFontMetricsF(layout->font()).horizontalAdvance(QLatin1Char(' '));
+                            #endif
                         if (w > space) {
                             x += w-space;
                             w = space;
                         }
                     }
                 } else
-                    w = QFontMetrics(layout->font()).width(QLatin1Char(' ')); // in sync with QTextLine::draw()
+                            #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+                            w = QFontMetrics(layout->font()).width(QLatin1Char(' ')); // in sync with QTextLine::draw()
+                            #else
+                            w = QFontMetrics(layout->font()).horizontalAdvance(QLatin1Char(' ')); // in sync with QTextLine::draw()
+                            #endif
 
                 QRectF rr = line.rect();
                 rr.moveTop(rr.top() + r.top());
@@ -790,7 +812,7 @@ block = block.next();
 
     if (backgroundVisible() && !block.isValid() && offset.y() <= er.bottom()
         && (centerOnScroll() || verticalScrollBar()->maximum() == verticalScrollBar()->minimum())) {
-        painter.fillRect(QRect(QPoint((int)er.left(), (int)offset.y()), er.bottomRight()), palette().background());
+        painter.fillRect(QRect(QPoint((int)er.left(), (int)offset.y()), er.bottomRight()), palette().window());
     }
     
 
@@ -817,6 +839,7 @@ if (inlinecheckSpelling && pChecker && !textCursor().hasSelection())
       int bpos=block.position();
       BlockData *data = static_cast<BlockData *>(c.block().userData() );
       QTextCodec *codec = QTextCodec::codecForName(spell_encoding.toLatin1());
+      if(!codec) codec = QTextCodec::codecForLocale();
       QByteArray encodedString;
       QString text,word;
       bool gonext=true;
@@ -889,25 +912,25 @@ if (inlinecheckSpelling && pChecker && !textCursor().hasSelection())
       }
 /*******************************************/
 a = menu->addAction(tr("Undo"), this, SLOT(undoText()));
-a->setShortcut(Qt::CTRL+Qt::Key_Z);
+a->setShortcut(Qt::CTRL | Qt::Key_Z);
 a->setEnabled(document()->isUndoAvailable());
 a = menu->addAction(tr("Redo") , this, SLOT(redoText()));
-a->setShortcut(Qt::CTRL+Qt::Key_Y);
+a->setShortcut(Qt::CTRL | Qt::Key_Y);
 a->setEnabled(document()->isRedoAvailable());
 menu->addSeparator();
 a = menu->addAction(tr("Cut"), this, SLOT(cut()));
-a->setShortcut(Qt::CTRL+Qt::Key_X);
+a->setShortcut(Qt::CTRL | Qt::Key_X);
 a->setEnabled(textCursor().hasSelection());
 a = menu->addAction(tr("Copy"), this, SLOT(copy()));
-a->setShortcut(Qt::CTRL+Qt::Key_C);
+a->setShortcut(Qt::CTRL | Qt::Key_C);
 a->setEnabled(textCursor().hasSelection());
 a = menu->addAction(tr("Paste") , this, SLOT(paste()));
-a->setShortcut(Qt::CTRL+Qt::Key_P);
+a->setShortcut(Qt::CTRL | Qt::Key_P);
 const QMimeData *md = QApplication::clipboard()->mimeData();
 a->setEnabled(md && canInsertFromMimeData(md));
 menu->addSeparator();
 a = menu->addAction(tr("Select All"), this, SLOT(selectAll()));
-a->setShortcut(Qt::CTRL+Qt::Key_A);
+a->setShortcut(Qt::CTRL | Qt::Key_A);
 a->setEnabled(!document()->isEmpty());
 menu->addSeparator();
 if (!document()->isEmpty() && !inlinecheckSpelling)
@@ -936,9 +959,9 @@ menu->addSeparator();
 a=new QAction(tr("Jump to pdf"),menu);
 a->setShortcut(vfocus);
 // #ifdef Q_WS_MACX
-// a->setShortcut(Qt::CTRL+Qt::Key_Dollar);
+// a->setShortcut(Qt::CTRL | Qt::Key_Dollar);
 // #else
-// a->setShortcut(Qt::CTRL+Qt::Key_Space);
+// a->setShortcut(Qt::CTRL | Qt::Key_Space);
 // #endif
 a->setData(QVariant(cursorForPosition(e->pos()).blockNumber() + 1));
 connect(a, SIGNAL(triggered()), this, SLOT(jumpToPdf()));
@@ -969,7 +992,7 @@ if (action)
 
 bool LatexEditor::search( const QString &expr, bool cs, bool wo, bool forward, bool startAtCursor, bool isRegExp)
 {
-QTextDocument::FindFlags flags = 0;
+QTextDocument::FindFlags flags = QTextDocument::FindFlags(0);
 if (cs) flags |= QTextDocument::FindCaseSensitively;
 if (wo) flags |= QTextDocument::FindWholeWords;
 QTextCursor c = textCursor();
@@ -987,7 +1010,7 @@ if (! startAtCursor)
 	setTextCursor(c);
 	}
 if (forward == false) flags |= QTextDocument::FindBackward;
-QTextCursor found = isRegExp?document()->find(QRegExp(expr), c, flags) : document()->find(expr, c, flags);
+QTextCursor found = isRegExp?document()->find(QRegularExpression(expr), c, flags) : document()->find(expr, c, flags);
 
 if (found.isNull()) return false;
 else 
@@ -999,11 +1022,11 @@ else
 
 int LatexEditor::searchInSelection( const QString &expr, bool cs, bool wo, bool isRegExp, int start, int end)
 {
-QTextDocument::FindFlags flags = 0;
+QTextDocument::FindFlags flags = QTextDocument::FindFlags(0);
 if (cs) flags |= QTextDocument::FindCaseSensitively;
 if (wo) flags |= QTextDocument::FindWholeWords;
 
-QTextCursor found = isRegExp?document()->find(QRegExp(expr), start, flags) : document()->find(expr, start, flags);
+QTextCursor found = isRegExp?document()->find(QRegularExpression(expr), start, flags) : document()->find(expr, start, flags);
 
 if (found.isNull()) return -1;
 else 
@@ -1038,14 +1061,17 @@ if (c.hasSelection())
 	{
 	if (isRegExp)
 	  {
-	  QRegExp expr1(o);
+	  QRegularExpression expr1(o);
+
 	  QStringList texts;
 	  QString rtext1=r;
 	  int pos = 0;
-	  while ((pos = expr1.indexIn(c.selectedText(), pos)) != -1) 
+        while (pos != -1)
 	    {
-	    texts << expr1.cap(1);
-	    pos += expr1.matchedLength();
+        QRegularExpressionMatch expr1Match=expr1.match(c.selectedText(),pos);
+	    texts << expr1Match.captured(1);
+        pos=expr1Match.capturedStart();
+	    pos += expr1Match.capturedLength(1);
 	    }
 	  for(int i = 0; i < 10 && i < texts.count(); i++)
 	    {
@@ -1390,7 +1416,7 @@ while (start > 0)
     isControlSeq = true;
     continue;
     }
-  if (!isControlSeq && (ch == '\'' || ch == 0x2019) && start > 0 && IS_WORD_BACK(text.at(start - 1))) 
+  if (!isControlSeq && (ch == '\'' || ch == QChar(0x2019)) && start > 0 && IS_WORD_BACK(text.at(start - 1)))
     {
     includesApos = true;
     continue;
@@ -1413,7 +1439,7 @@ while (++end < text.length())
     isControlSeq = true;
     continue;
     }
-  if (!isControlSeq && (ch == '\'' || ch == 0x2019) && end < text.length() - 1 && IS_WORD_FORWARD(text.at(end + 1))) 
+  if (!isControlSeq && (ch == '\'' || ch == QChar(0x2019)) && end < text.length() - 1 && IS_WORD_FORWARD(text.at(end + 1)))
   {
   includesApos = true;
   continue;
@@ -1535,7 +1561,7 @@ while (start > 0)
     isControlSeq = true;
     continue;
     }
-  if (!isControlSeq && (ch == '\'' || ch == 0x2019) && start > 0 && IS_WORD_FORMING(text.at(start - 1))) 
+  if (!isControlSeq && (ch == '\'' || ch == QChar(0x2019)) && start > 0 && IS_WORD_FORMING(text.at(start - 1)))
     {
     includesApos = true;
     continue;
@@ -1564,7 +1590,7 @@ while (++end < text.length())
     isControlSeq = true;
     continue;
     }
-  if (!isControlSeq && (ch == '\'' || ch == 0x2019) && end < text.length() - 1 && IS_WORD_FORMING(text.at(end + 1))) 
+  if (!isControlSeq && (ch == '\'' || ch == QChar(0x2019)) && end < text.length() - 1 && IS_WORD_FORMING(text.at(end + 1)))
   {
   includesApos = true;
   continue;
@@ -1706,10 +1732,10 @@ else if ( e->key()==Qt::Key_Tab)
     if (block.isValid()) 
 	{
 	QString txt=block.text();
-	if (txt.contains(QString(0x2022)))
+	if (txt.contains(QString(QChar(0x2022))))
 	    {
 	    //e->ignore();
-	    search(QString(0x2022) ,true,false,true,true,false);
+	    search(QString(QChar(0x2022)) ,true,false,true,true,false);
 	    return;		
 	    }
 	}
@@ -1717,10 +1743,10 @@ else if ( e->key()==Qt::Key_Tab)
     if (blocknext.isValid()) 
 	{
 	QString txtnext=blocknext.text();
-	if (txtnext.contains(QString(0x2022)))
+	if (txtnext.contains(QString(QChar(0x2022))))
 	    {
 	    //e->ignore();
-	    search(QString(0x2022) ,true,false,true,true,false);
+	    search(QString(QChar(0x2022)) ,true,false,true,true,false);
 	    return;		
 	    }
 	}
@@ -1734,10 +1760,10 @@ else if ( e->key()==Qt::Key_Backtab)
     if (block.isValid()) 
 	{
 	QString txt=block.text();
-	if (txt.contains(QString(0x2022)))
+	if (txt.contains(QString(QChar(0x2022))))
 	    {
 	    //e->ignore();
-	    search(QString(0x2022) ,true,false,false,true,false);
+	    search(QString(QChar(0x2022)) ,true,false,false,true,false);
 	    return;		
 	    }
 	}
@@ -1750,13 +1776,13 @@ else if ( e->key()==Qt::Key_Backtab)
 // if (((e->modifiers() & ~Qt::ShiftModifier) == Qt::ControlModifier) && e->key()==Qt::Key_Tab) 
 //   {
 //   e->ignore();
-//   search(QString(0x2022) ,true,true,true,true);
+//   search(QString(QChar(0x2022)) ,true,true,true,true);
 //   return;
 //   }
 // if (((e->modifiers() & ~Qt::ShiftModifier) == Qt::ControlModifier) && e->key()==Qt::Key_Backtab) 
 //   {
 //   e->ignore();
-//   search(QString(0x2022) ,true,true,false,true);
+//   search(QString(QChar(0x2022)) ,true,true,false,true);
 //   return;
 //   }
 // if ((e->key()==Qt::Key_Backtab))
@@ -1829,22 +1855,24 @@ else
 		  if (startw<0) startw=0;
 		  cursor.setPosition(startw,QTextCursor::MoveAnchor);
 		  cursor.setPosition(endw, QTextCursor::KeepAnchor);
-		  //qDebug() << trigger << startw << endw << cursor.selectedText();
 		    if ((trigger!=":") && (trigger==cursor.selectedText()))
 		      {
-			QRegExp rx("(@+)");
+			QRegularExpression rx("(@+)");
 			int index=0;
-			while ((index = rx.indexIn(code,index)) != -1) 
+			//while ((index = rx.indexIn(code,index)) != -1)
+            while (index != -1)
 			{
-			if (rx.cap(1)=="@") code.replace(rx.pos(1),1,QString(0x2022));
-			else if (rx.cap(1)=="@@") code.replace(rx.pos(1),2,"@");
-			index += rx.matchedLength();
+            QRegularExpressionMatch rxMatch=rx.match(code,index);
+			if (rxMatch.captured(1)=="@") code.replace(rxMatch.capturedStart(1),1,QString(QChar(0x2022)));
+			else if (rxMatch.captured(1)=="@@") code.replace(rxMatch.capturedStart(1),2,"@");
+            index=rxMatch.capturedStart(1);
+			index += rxMatch.capturedLength(1);
 			}
-		      //code.replace("@",QString(0x2022));
+		      //code.replace("@",QString(QChar(0x2022)));
 		      if (code.left(1)=="%")
 			{
 			code=code.remove(0,1);
-			code="\\begin{"+code+"}\n"+QString(0x2022)+"\n\\end{"+code+"}\n";
+			code="\\begin{"+code+"}\n"+QString(QChar(0x2022))+"\n\\end{"+code+"}\n";
 			}
 		      search(trigger, true, false,false,true,false);
 		      int pos=cursor.position();
@@ -1852,12 +1880,12 @@ else
 		      insertWithMemoryIndent(code);
 		      //replace(code,false,"");
 		      //int pos=cursor.position();
-		      if (code.contains(QString(0x2022))) 
+		      if (code.contains(QString(QChar(0x2022))))
 			{
 			cursor.setPosition(pos,QTextCursor::MoveAnchor);
 			setTextCursor(cursor);
-			//search(QString(0x2022) ,true,false,false,true,false);
-			search(QString(0x2022) ,true,false,true,true,false);
+			//search(QString(QChar(0x2022)) ,true,false,false,true,false);
+			search(QString(QChar(0x2022)) ,true,false,true,true,false);
 			}
 		      else 
 			{
@@ -1872,7 +1900,7 @@ else
 	      }
 	  if (!found) QPlainTextEdit::keyPressEvent(e);
 	  }
-	else if (s1.matches(QKeySequence(Qt::CTRL + Qt::Key_S))!=QKeySequence::ExactMatch && s1.matches(QKeySequence(Qt::CTRL + Qt::Key_Y))!=QKeySequence::ExactMatch) QPlainTextEdit::keyPressEvent(e);
+	else if (s1.matches(QKeySequence(Qt::CTRL  | Qt::Key_S))!=QKeySequence::ExactMatch && s1.matches(QKeySequence(Qt::CTRL  | Qt::Key_Y))!=QKeySequence::ExactMatch) QPlainTextEdit::keyPressEvent(e);
 	}
 if (c && !c->popup()->isVisible()) 
 	{
@@ -1975,13 +2003,11 @@ QObject::connect(c, SIGNAL(activated(const QString&)),this, SLOT(insertCompletio
 {
 if (c->widget() != this) return;
 QTextCursor tc = textCursor();
-//tc.select(QTextCursor::WordUnderCursor);
-//qDebug() << tc.selectedText();
 QStringList check=fullcommandUnderCursor();
 int t=check.at(1).toInt();
 int r=check.at(2).toInt();
 int w=check.at(0).size();
-//qDebug() << check << w;
+
 
 QString insert_word = completion;
 
@@ -1991,29 +2017,28 @@ tc.removeSelectedText();
 int pos=tc.position();
 tc.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor,w-t-1+r);
 QString aft=tc.selectedText();
-//qDebug() << bef << aft;
-//tc.removeSelectedText();
 if (bef.contains("{") || (!aft.contains("}") && !aft.contains("]"))) tc.removeSelectedText();
 else tc.setPosition(pos,QTextCursor::MoveAnchor);
 
 QString env;
-QRegExp rbb("begin\\{\\s*([A-Za-z_]+(\\*)?)\\}");
+QRegularExpression rbb("begin\\{\\s*([A-Za-z_]+(\\*)?)\\}");
+QRegularExpressionMatch rbbMatch=rbb.match(completion);
 //QRegExp rbb("begin\\{\\s*(.*)\\}");
-if (completion.contains(rbb)) 
+if (rbbMatch.hasMatch())
 	{
 	tc.insertText(insert_word);
 	insertNewLine();
 	insertNewLine();
 	tc.select(QTextCursor::WordUnderCursor);
-	env=rbb.cap(1);
+	env=rbbMatch.captured(1);
 	tc.insertText("\\end{"+env+"}");
 	tc.movePosition(QTextCursor::Up,QTextCursor::MoveAnchor,1);
 	setTextCursor(tc);
-	if (insert_word.contains(QString(0x2022)))
+	if (insert_word.contains(QString(QChar(0x2022))))
 	    {
 	    tc.movePosition(QTextCursor::Up,QTextCursor::MoveAnchor,1);
 	    setTextCursor(tc);
-	    search(QString(0x2022) ,true,false,true,true,false);
+	    search(QString(QChar(0x2022)) ,true,false,true,true,false);
 	    emit tooltiptab();
 	    }
 
@@ -2023,12 +2048,12 @@ else
 	tc.insertText(insert_word);
 	tc.setPosition(pos,QTextCursor::MoveAnchor);
 	setTextCursor(tc);
-	if (!insert_word.contains(QString(0x2022)))
+	if (!insert_word.contains(QString(QChar(0x2022))))
 	  {
 	  tc.setPosition(pos+completion.length(),QTextCursor::MoveAnchor);
 	  setTextCursor(tc);
 	  }
-	else if (!search(QString(0x2022) ,true,false,true,true,false))
+	else if (!search(QString(QChar(0x2022)) ,true,false,true,true,false))
 	  {
 	  tc.setPosition(pos+completion.length(),QTextCursor::MoveAnchor);
 	  setTextCursor(tc);
@@ -2413,12 +2438,22 @@ ensureCursorVisible();
 
 void LatexEditor::checkStructUpdate(QTextDocument *doc,int blockpos,QString text,int line)
 {
-QList<StructItem> temp=StructItemsList;
-QBrush brushcomment(highlighter->ColorComment);
-QFuture< struct updateStruct > result=QtConcurrent::run(updateStructureList,doc,blockpos,text,line,temp);
-struct updateStruct newstruct=result;
+ QList<StructItem> temp=StructItemsList;
+ QBrush brushcomment(highlighter->ColorComment);
+ QFuture< struct updateStruct > result=QtConcurrent::run(updateStructureList,doc,blockpos,text,line,temp);
+ struct updateStruct newstruct;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+newstruct=result;
 StructItemsList=newstruct.list;
 if (newstruct.isdirty) {emit requestUpdateStructure();}
+#else
+if (result.isValid())
+    {
+    newstruct=result.result();
+    StructItemsList=newstruct.list;
+    if (newstruct.isdirty) {emit requestUpdateStructure();}
+    }
+#endif
 }
 
 
@@ -2496,7 +2531,11 @@ void LatexEditor::setTabSettings(bool tabspaces,int tabwidth)
 {
 tabWidth=tabwidth;
 tabSpaces=tabspaces;
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 setTabStopWidth(fontMetrics().width(" ")*tabWidth);
+#else
+setTabStopDistance(fontMetrics().horizontalAdvance(" ")*tabWidth);
+#endif
 }
 
 void LatexEditor::requestNewNumLines(int n)
@@ -2536,7 +2575,11 @@ if (e->modifiers() & Qt::AltModifier)
 	// get visual column
 	int column = blockSelection.columnAt(cursor.block().text(), cursor.positionInBlock());
 	if (cursor.positionInBlock() == cursor.block().length()-1) {
+        #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 	    column += (e->pos().x() - cursorRect().center().x())/QFontMetricsF(font()).width(QLatin1Char(' '));
+        #else
+        column += (e->pos().x() - cursorRect().center().x())/QFontMetricsF(font()).horizontalAdvance(QLatin1Char(' '));
+        #endif
 	}
 	  blockSelection.moveAnchor(cursor.blockNumber(), column);
 	setTextCursor(blockSelection.selection());
@@ -2654,7 +2697,7 @@ QMimeData *LatexEditor::createMimeDataFromSelection() const
             const int endOfDocument = tempDocument->characterCount() - 1;
             for (QTextBlock current = start; current.isValid() && current != end; current = current.next()) {
                 const QTextLayout *layout = current.layout();
-                foreach (const QTextLayout::FormatRange &range, layout->additionalFormats()) {
+                foreach (const QTextLayout::FormatRange &range, layout->formats()) {
                     const int start = current.position() + range.start - selectionStart;
                     const int end = start + range.length;
                     if (end <= 0 || start >= endOfDocument)
@@ -2878,9 +2921,9 @@ void LatexEditor::dropEvent(QDropEvent *event)
 {
 event->acceptProposedAction();
 #if defined(Q_OS_WIN32)
-QRegExp rxpics("file:(/+)(.*\\.(?:eps|pdf|png|jpeg|jpg|tiff))");
+QRegularExpression rxpics("^file:(/+)(.*\\.(?:eps|pdf|png|jpeg|jpg|tiff))$");
 #else
-QRegExp rxpics("file:(//)(.*\\.(?:eps|pdf|png|jpeg|jpg|tiff))");
+QRegularExpression rxpics("^file:(//)(.*\\.(?:eps|pdf|png|jpeg|jpg|tiff))$");
 #endif
 QList<QUrl> uris=event->mimeData()->urls();
 if (event && (uris.size()>0))
@@ -2895,9 +2938,10 @@ QPlainTextEdit::dropEvent(event);
 cursor.setPosition(initialCursorPosition,QTextCursor::MoveAnchor);
 cursor.setPosition(initialCursorPosition+uri.length(),QTextCursor::KeepAnchor);
 cursor.removeSelectedText();
-if (rxpics.exactMatch(uri))
+QRegularExpressionMatch rxpicsMatch=rxpics.match(uri);
+if (rxpicsMatch.hasMatch())
   {
-  fn=rxpics.cap(2);
+  fn=rxpicsMatch.captured(2);
   if (!fname.startsWith("untitled"))
       {
       QFileInfo fi(fname);
@@ -2919,17 +2963,7 @@ QPlainTextEdit::dropEvent(event);
 }
 }
 
-/*const QRectF LatexEditor::blockGeometry(const QTextBlock & block) 
-{
-qDebug() << "ok1" << block.isValid() << block.isVisible();
-//if (block.isVisible()) return blockBoundingGeometry(block).translated(contentOffset());
-//else return QRectF();
-return blockBoundingGeometry(block).translated(contentOffset());
-//const QRectF rec=blockBoundingGeometry(block);
-//qDebug() << "ok2";
-//if (rec.isValid()) return rec.translated(contentOffset());
-//else return QRectF();
-}*/
+
 
 /*** SCRIPT ***/
 void LatexEditor::ExecuteScript(QString location)
@@ -2942,10 +2976,14 @@ if ( !location.isEmpty() )
 	if (scriptfile.open(QFile::ReadOnly))
 	    {
 	    QTextStream ts_script(&scriptfile);
-	    ts_script.setCodec(codec);
+        #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        ts_script.setCodec(codec);
+        #else
+        ts_script.setEncoding(QStringConverter::Encoding::Utf8);
+        #endif
 	    text= ts_script.readAll();
 	    }
-	QScriptValue result = fScriptEngine.evaluate(text);
+QJSValue result = fScriptEngine.evaluate(text);
 	}
 }
 
