@@ -1,14 +1,16 @@
 /***************************************************************************
- *   copyright       : (C) 2012-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
- *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
+ *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
+
 /*
 
 Copyright 2012 Adam Reichold
@@ -137,7 +139,7 @@ QAction *act = menu.addAction(tr("Click to jump to the line")+" (cmd+click)");
 QAction *act = menu.addAction(tr("Click to jump to the line")+" (ctrl+click)");
 #endif
 
-//act->setShortcut(Qt::CTRL+Qt::Key_Space);
+//act->setShortcut(Qt::CTRL | Qt::Key_Space);
 act->setData(QVariant(event->pos()));
 connect(act, SIGNAL(triggered()), this, SLOT(jumpToSourceFromPdf()));
 
@@ -153,6 +155,10 @@ act = menu.addAction(tr("Convert page to png image"));
 act->setData(QVariant(event->pos()));
 connect(act, SIGNAL(triggered()), this, SLOT(requestPngExport()));
 
+act = menu.addAction(tr("Check Spelling and Grammar on this page"));
+act->setData(QVariant(event->pos()));
+connect(act, SIGNAL(triggered()), this, SLOT(requestCheckGrammar()));
+
 act = menu.addAction(tr("Open the file browser"));
 act->setData(QVariant(event->pos()));
 connect(act, SIGNAL(triggered()), this, SLOT(requestOpenLocation()));
@@ -179,8 +185,11 @@ void PageItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget
         {
             image = m_image;
             m_image = QImage();
-
+            #if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
             s_cache.insert(this, new QImage(image), image.byteCount());
+            #else
+            s_cache.insert(this, new QImage(image), image.sizeInBytes());
+            #endif
         }
         else
         {
@@ -239,31 +248,25 @@ if (qApp->devicePixelRatio()>=2) image.setDevicePixelRatio(qApp->devicePixelRati
     }
 
     QColor selBlendColor=QColor("#FF0000");
-    QColor blCol = selBlendColor.dark( 140 );
+    QColor blCol = selBlendColor.darker( 140 );
     blCol.setAlphaF( 0.2 );
 
     if (!searchPath.isEmpty()) 
       {
-      QRect highlightRect = matrix().mapRect(searchPath.boundingRect()).toRect();
+      QRect highlightRect = searchPath.boundingRect().toRect(); //transform().mapRect(searchPath.boundingRect()).toRect();
       highlightRect.adjust(-3, -2, 3, 0);
-//      QImage highlight = image.copy(highlightRect);
-//      painter.begin(&image);
       painter->fillRect(highlightRect, blCol);
       painter->setPen( selBlendColor );
       painter->drawRect( highlightRect );
-//      painter.end();
       }
-    if (!highlightPath.isEmpty()) 
+    if (!highlightPath.isEmpty())
       {
-      QRect highlightRect = matrix().mapRect(highlightPath.boundingRect()).toRect();
+      QRect highlightRect = highlightPath.boundingRect().toRect(); //matrix().mapRect(highlightPath.boundingRect()).toRect();
       highlightRect.adjust(-3, -2, 3, 0);
-//      QImage highlight = image.copy(highlightRect);
-//      painter.begin(&image);
       painter->fillRect(highlightRect, blCol);
       painter->setPen( selBlendColor );
       painter->drawRect( highlightRect );
-//      painter.end();
-      }    
+      }
     
     painter->restore();
 
@@ -388,7 +391,11 @@ void PageItem::startRender(bool prefetch)
 {
     if(!m_render->isRunning())
     {
+        #if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+        m_render->setFuture(QtConcurrent::run(&PageItem::render,this, m_physicalDpiX, m_physicalDpiY, m_scaleFactor, m_rotation, prefetch));
+        #else
         m_render->setFuture(QtConcurrent::run(this, &PageItem::render, m_physicalDpiX, m_physicalDpiY, m_scaleFactor, m_rotation, prefetch));
+        #endif
     }
 }
 
@@ -420,7 +427,11 @@ void PageItem::on_imageReady(QImage image, bool prefetch)
     }
     else
     {
-        s_cache.insert(this, new QImage(image), image.byteCount());
+            #if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
+            s_cache.insert(this, new QImage(image), image.byteCount());
+            #else
+            s_cache.insert(this, new QImage(image), image.sizeInBytes());
+            #endif
     }
 }
 
@@ -737,7 +748,10 @@ void PageItem::requestPngExport()
 {
 emit wantPngExport(m_index);
 }
-
+void PageItem::requestCheckGrammar()
+{
+emit wantCheckGrammar(m_index);
+}
 void PageItem::requestOpenLocation()
 {
 emit wantOpenLocation();
