@@ -1,13 +1,14 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
- *   addons by Luis Silvestre                           *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
+ *   addons by Luis Silvestre ; S. Razi Alavizadeh; Robin.Watts            *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #ifndef TEXMAKER_H
@@ -171,6 +172,7 @@ bool showEmphasis, showNewline, showMathmode, showIndice, showPuissance, showSma
 QComboBox *comboCompil, *comboView, *comboFiles;
 DropShadowLabel *titleLeftPanel, *posLabel, *stat1, *stat2, *stat3;
 
+
 QPushButton *pb1, *pb2, *pb3;
 QString MasterName;
 bool logpresent;
@@ -222,9 +224,9 @@ QString pdfCheckerLang;
 //X11
 #if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
 QString x11style;
+#endif
 QString x11fontfamily;
 int x11fontsize;
-#endif
 SymbolList symbolScore;
 usercodelist symbolMostused;
 QList<int> favoriteSymbolList;
@@ -552,6 +554,7 @@ void SaveLastSession();
 void LoadLastSession();
 
 void compareDocuments();
+void setScale();
 
 protected:
 void dragEnterEvent(QDragEnterEvent *event);
