@@ -1,12 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "unicodeview.h"
@@ -17,10 +18,14 @@
 #include <QFileDialog>
 #include <QTextBlock>
 #include <QLineEdit>
-#include <QTextCodec>
 #include <QTextStream>
 #include <QFile>
 #include <QMessageBox>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    #include <QtCore/QTextCodec>
+#else
+    #include <QtCore5Compat/QTextCodec>
+#endif
 
 #include "geticon.h"
 
@@ -39,7 +44,7 @@ QFrame *framebis=new QFrame(splitter);
 
 QVBoxLayout* mainlay = new QVBoxLayout(framebis );
 mainlay->setSpacing(0);
-mainlay->setMargin(0);
+mainlay->setContentsMargins(0,0,0,0);
 
 centralToolBar=new QToolBar("ToolBar",framebis);
 centralToolBar->setFloatable(false);
@@ -70,10 +75,14 @@ connect(editor, SIGNAL(requestGotoLine()), this, SLOT(showGoto()));
 m_lineNumberWidget = new LightLineNumberWidget( editor, frame);
 m_lineNumberWidget->setFont(efont);
 QFontMetrics fm( efont );
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 m_lineNumberWidget->setFixedWidth( fm.width( "00000" ) + 22 );
+#else
+m_lineNumberWidget->setFixedWidth( fm.horizontalAdvance( "00000" ) + 22 );
+#endif
 QHBoxLayout* lay = new QHBoxLayout( frame );
 lay->setSpacing(0);
-lay->setMargin(0);
+lay->setContentsMargins(0,0,0,0);
 lay->addWidget( m_lineNumberWidget );
 lay->addWidget( editor );
 setFocusProxy( editor );
@@ -102,7 +111,7 @@ splitter->addWidget(Stack);
 
 QVBoxLayout *mainlayout= new QVBoxLayout(this);
 mainlayout->setSpacing(0);
-mainlayout->setMargin(0);
+mainlayout->setContentsMargins(0,0,0,0);
 mainlayout->addWidget(splitter);
 }
 
@@ -124,7 +133,11 @@ void UnicodeView::changeSettings(QFont & new_font,bool line)
   editor->changeFont(new_font);
   m_lineNumberWidget->setFont(new_font);
   QFontMetrics fm( new_font );
+  #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
   m_lineNumberWidget->setFixedWidth( fm.width( "00000" ) + 32 );
+  #else
+  m_lineNumberWidget->setFixedWidth( fm.horizontalAdvance( "00000" ) + 32 );
+  #endif
   setLineNumberWidgetVisible(line);
 }
 
@@ -148,7 +161,11 @@ if ( !fn.isEmpty() )
 		}
 	QTextStream ts( &file );
 	QTextCodec* codec = QTextCodec::codecForName(QString("UTF-8").toLatin1());
-	ts.setCodec(codec);
+    #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    ts.setCodec(codec);
+    #else
+    ts.setEncoding(QStringConverter::Encoding::Utf8);
+    #endif
 	ts << editor->toPlainText();
 	file.close();
 	lastdocument=fn;
