@@ -1,12 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include <QHeaderView>
@@ -52,7 +53,8 @@ userlist.append(cmd);
 if (ui.listWidget->count()>0)
 	{
 	ui.listWidget->setCurrentItem(ui.listWidget->item(ui.listWidget->count()-1));
-	ui.listWidget->setItemSelected(ui.listWidget->currentItem(), true);
+    ui.listWidget->currentItem()->setSelected(true);
+	//ui.listWidget->setItemSelected(ui.listWidget->currentItem(), true);
 	}
 }
 
@@ -63,9 +65,15 @@ if (current<=0) return;
 QListWidgetItem *item=ui.listWidget->item(current)->clone();
 delete ui.listWidget->item(current);
 ui.listWidget->insertItem(current-1,item);
+#if QT_VERSION < QT_VERSION_CHECK(5,13,0)
 userlist.swap(current,current-1);
+#else
+userlist.swapItemsAt(current,current-1);
+#endif
+
 ui.listWidget->setCurrentItem(ui.listWidget->item(current-1));
-ui.listWidget->setItemSelected(ui.listWidget->item(current-1),true);
+ui.listWidget->currentItem()->setSelected(true);
+//ui.listWidget->setItemSelected(ui.listWidget->item(current-1),true);
 updateQuickCommand();
 }
 
@@ -76,9 +84,15 @@ if (current>=ui.listWidget->count()-1 || current<0) return;
 QListWidgetItem *item=ui.listWidget->item(current)->clone();
 delete ui.listWidget->item(current);
 ui.listWidget->insertItem(current+1,item);
+#if QT_VERSION < QT_VERSION_CHECK(5,13,0)
 userlist.swap(current,current+1);
+#else
+userlist.swapItemsAt(current,current+1);
+#endif
+
 ui.listWidget->setCurrentItem(ui.listWidget->item(current+1));
-ui.listWidget->setItemSelected(ui.listWidget->item(current+1),true);
+ui.listWidget->currentItem()->setSelected(true);
+//ui.listWidget->setItemSelected(ui.listWidget->item(current+1),true);
 updateQuickCommand();
 }
 
@@ -92,12 +106,14 @@ userlist.removeAt(current);
 if (current==ui.listWidget->count())
 	{
 	ui.listWidget->setCurrentItem(ui.listWidget->item(current-1));
-	ui.listWidget->setItemSelected(ui.listWidget->item(current-1),true);
+    ui.listWidget->currentItem()->setSelected(true);
+	//ui.listWidget->setItemSelected(ui.listWidget->item(current-1),true);
 	}
 else
 	{
 	ui.listWidget->setCurrentItem(ui.listWidget->item(current));
-	ui.listWidget->setItemSelected(ui.listWidget->item(current),true);
+    ui.listWidget->currentItem()->setSelected(true);
+	//ui.listWidget->setItemSelected(ui.listWidget->item(current),true);
 	}
 updateQuickCommand();
 }
